antares.apps.notifications.models package
=========================================

Submodules
----------

antares.apps.notifications.models.notification\_record module
-------------------------------------------------------------

.. automodule:: antares.apps.notifications.models.notification_record
   :members:
   :undoc-members:
   :show-inheritance:

antares.apps.notifications.models.notification\_rule module
-----------------------------------------------------------

.. automodule:: antares.apps.notifications.models.notification_rule
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.notifications.models
   :members:
   :undoc-members:
   :show-inheritance:
